Module util

Module util 

Various utilities for working with windows. Includes utilities for converting between Windows and Rust types, including strings. Also includes some code to dynamically load functions at runtime. This is needed for functions which are only supported on certain versions of windows.

Structs

OPTIONAL_FUNCTIONS
OptionalFunctions

Enums

Error
Error codes. At the moment, this is little more than HRESULT, but that might change.

Traits

FromWide
ToWide

Functions

as_result
default_text_options
Determine a suitable default set of text options. Enables color fonts on systems that are capable of them (8.1 and above).
init
Initialize the app. At the moment, this is mostly needed for hi-dpi.