Module window

Module window 

Creation and management of windows.

Structs

IdleHandle
A handle that can get used to schedule an idle handler. Note that this handle is thread safe. If the handle is used after the hwnd has been destroyed, probably not much will go wrong (the XI_RUN_IDLE message may be sent to a stray window).
MouseEvent
A mouse button press or release event.
WindowBuilder
Builder abstraction for creating new windows.
WindowHandle

Enums

Cursor
Standard cursor types. This is only a subset, others can be added as needed.
MouseButton
An indicator of which mouse button was pressed.
MouseType
An indicator of the state change of a mouse button.
PresentStrategy
It’s very tricky to get smooth dynamics (especially resizing) and good performance on Windows. This setting lets clients experiment with different strategies.

Constants

M_ALT
Modifier mask for alt key in keydown and char events.
M_CTRL
Modifier mask for control key in keydown and char events.
M_SHIFT
Modifier mask for shift key in keydown and char events.

Traits

WinHandler
App behavior, supplied by the app.

Functions

DwmFlush