IdleHandle

Struct IdleHandle 

pub struct IdleHandle { /* private fields */ }
A handle that can get used to schedule an idle handler. Note that this handle is thread safe. If the handle is used after the hwnd has been destroyed, probably not much will go wrong (the XI_RUN_IDLE message may be sent to a stray window).

Implementations

Source

impl IdleHandle

pub fn add_idle<F>(&self, callback: F)
where F: FnOnce(&dyn Any) + Send + 'static,

Add an idle handler, which is called (once) when the message loop is empty. The idle handler will be run from the window’s wndproc, which means it won’t be scheduled if the window is closed.